<?xml version="1.0" encoding="UTF-8"?>
<!-- bm801_537v2.0_Vecozo_stap1_v1, januari 2024 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:cod="http://ei.vektis.nl/codelijsten/v1"
xmlns:bm801="http://ei.vektis.nl/betaalopdrachtmondzorg/bm801/v2_0"
xmlns:bm802="http://ei.vektis.nl/betaalopdrachtmondzorg/bm802/v2_0">

	<!-- VALXSLT 2 TRAPS RETOURBERICHT  - versie Vecozo -->
	<!-- Deze xslt doet stap 1, i.e. tussenresultaat retourbericht met alle klassen, identificerende gegevens van klassen en geconstateerde fouten -->
	<!-- Laden Configuratiefile met waarde voor Omgeving en Huidige datum	-->

	<xsl:import href="config_Vecozo.xml"/>
	<xsl:import href="rcCode_vs_Peildatum.xslt"/>
	<xsl:import href="rcDatum_vs_Peildatum.xslt"/>
	<xsl:import href="rcDatum_vs_Huidigedatum.xslt"/>
  	<xsl:import href="rc8028.xslt"/>
	<xsl:import href="rc8987.xslt"/>
	<xsl:import href="rc8988.xslt"/>
	<xsl:import href="rc8991.xslt"/>
	<xsl:import href="rc9262a.xslt"/>
	<xsl:import href="rc9263a.xslt"/>
	<xsl:import href="rc9644.xslt"/>	
	<xsl:import href="rc9645.xslt"/>	
	<xsl:import href="rc9646.xslt"/>	
	<xsl:import href="rc9647.xslt"/>		
	<xsl:import href="rc9650.xslt"/>		
	
	<!-- Uitvoer is bm802_538 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />

	<xsl:variable name="Berichtsoort" select="//bm801:Bericht/bm801:Header/bm801:Berichtsoort"/> 
	<xsl:variable name="Berichtcode" select="//bm801:Bericht/bm801:Header/bm801:Berichtcode"/> 
	<xsl:variable name="VerzenderRol" select="//bm801:Bericht/bm801:Header/bm801:VerzenderRol"/>
	<xsl:variable name="OntvangerRol" select="//bm801:Bericht/bm801:Header/bm801:OntvangerRol"/> 
	<xsl:variable name="Verzenddatum" select="//bm801:Bericht/bm801:Header/bm801:Verzenddatum"/>
	<xsl:variable name="TotaalBedrag" select="//bm801:Bericht/bm801:Overzicht/bm801:TotaalBedragDC/bm801:Bedrag"/> 
	<xsl:variable name="TotaalBedragDCIndicator" select="//bm801:Bericht/bm801:Overzicht/bm801:TotaalBedragDC/bm801:DebetCreditCode"/> 
		
	<!-- Controleer op fouten in de Header -->
	<!-- RC003: VerzenderRol moet voorkomen in ketenpartij codelijst. | Indien VerzenderRol in ketenpartij voorkomt, dan moet de waarde van Verzenddatum groter zijn dan of gelijk zijn aan de waarde van ingangsdatum ketenpartij van VerzenderRol. | Indien expiratiedatum ketenpartij gevuld is, dan moet de waarde van Verzenddatum kleiner zijn dan de waarde van expiratiedatum ketenpartij van VerzenderRol. -->
	<xsl:variable name="rc003">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/CL0002-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9302'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'9303'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'9304'"/>
			<xsl:with-param name="Code" select="$VerzenderRol"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- RC006: OntvangerRol moet voorkomen in ketenpartij codelijst. | Indien OntvangerRol in ketenpartij voorkomt, dan moet de waarde van Verzenddatum groter zijn dan of gelijk zijn aan de waarde van ingangsdatum ketenpartij van OntvangerRol. | Indien expiratiedatum ketenpartij gevuld is, dan moet de waarde van Verzenddatum kleiner zijn dan de waarde van expiratiedatum ketenpartij van OntvangerRol. -->
	<xsl:variable name="rc006">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/CL0002-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9311'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'9312'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'9313'"/>
			<xsl:with-param name="Code" select="$OntvangerRol"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC001: De waarde van Berichtsoort moet voldoen aan de omgeving van VECOZO (productie of test) -->
	<xsl:variable name="vc001">
		<xsl:call-template name="rc8028">
			<xsl:with-param name="Berichtsoort" select="$Berichtsoort"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC007: Indien Berichtcode = 537 (= Betaalopdracht Wlz), dan  VerzenderRol = 5 (= Zorgkantoor). -->
	<xsl:variable name="vc007">
		<xsl:call-template name="rc9262a">
			<xsl:with-param name="Berichtcode" select="$Berichtcode"/>
			<xsl:with-param name="VerzenderRol" select="$VerzenderRol"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC009: Indien Berichtcode = 537 (= Betaalopdracht in de WLZ), dan OntvangerRol = 7 (= CAK). -->
	<xsl:variable name="vc009">
		<xsl:call-template name="rc9263a">
			<xsl:with-param name="Berichtcode" select="$Berichtcode"/>
			<xsl:with-param name="OntvangerRol" select="$OntvangerRol"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC011: De waarde van Verzenddatum moet kleiner zijn dan of gelijk zijn aan de waarde van huidige datum. -->
	<xsl:variable name="vc011">
		<xsl:call-template name="rcDatum_vs_Huidigedatum">
			<xsl:with-param name="TeControlerenDatum" select="$Verzenddatum"/>
			<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
			<xsl:with-param name="Retourcode" select="'8986'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- Zet variabele als er geen fouten zijn opgetreden in de Header -->
	<xsl:variable name="FoutInHeader">
		<xsl:if test="$rc003='' and $rc006='' and $vc001='' and $vc007='' and $vc009='' and $vc011=''">false</xsl:if>
	</xsl:variable>

	<!-- Controleer op fouten in Overzicht -->
	<!-- VC002: TotaalBedragDC included DebetCreditCode = SOM Betaalopdracht/BedragDC included DebetCreditCode | Som totaalbedrag ontbreekt of is onjuist.  -->
	<xsl:variable name="vc002">
		<xsl:call-template name="rc8987">
			<xsl:with-param name="TotaalBedrag" select="$TotaalBedrag"/>
			<xsl:with-param name="TotaalBedragDCIndicator" select="$TotaalBedragDCIndicator"/>
			<xsl:with-param name="TotaalDebetPrestaties" select="sum(//bm801:Bericht/bm801:Betaalopdracht/bm801:BedragDC[bm801:DebetCreditCode = 'D']/bm801:Bedrag)"/>
			<xsl:with-param name="TotaalCreditPrestaties" select="sum(//bm801:Bericht/bm801:Betaalopdracht/bm801:BedragDC[bm801:DebetCreditCode = 'C']/bm801:Bedrag)"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- RC014: DebetCreditCode moet voorkomen in Indicatie debet/credit. -->
	<xsl:variable name="rc014">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
			<xsl:with-param name="Code" select="$TotaalBedragDCIndicator"/>
			<xsl:with-param name="Peildatum" select="geenpeildatum"/>
		</xsl:call-template>
	</xsl:variable>		
	<!-- Zet variabele als er geen fouten zijn opgetreden in de VerantwoordingsContext -->
	<xsl:variable name="FoutInOverzicht">
		<xsl:if test="$vc002='' and $rc014=''">false</xsl:if>
	</xsl:variable>	
	
	<xsl:template match="bm801:Bericht">
		<bm802:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/betaalopdrachtmondzorg/bm802/v2_0 bm802v2_538.xsd</xsl:attribute>
			<xsl:choose>
				<!-- Geen errors in de Header, VerantwoordingsContext of Overzicht dan hele bericht als retour -->
				<xsl:when test="$FoutInHeader='false' and $FoutInOverzicht='false'">
					<xsl:apply-templates select="bm801:Header"/>
					<xsl:apply-templates select="bm801:Overzicht"/>
					<xsl:apply-templates select="bm801:Betaalopdracht"/>
  				</xsl:when>
				<!-- Wel errors in de Header, VerantwoordingsContext of Overzicht dan alleen Header, VerantwoordingsContext en Overzicht als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="bm801:Header"/>
					<xsl:apply-templates select="bm801:Overzicht"/>
				</xsl:otherwise>
			</xsl:choose>				
		</bm802:Bericht>
	</xsl:template>

	<xsl:template match="bm801:Header">
		<bm802:Header>
			<bm802:Berichtcode>538</bm802:Berichtcode>
			<xsl:apply-templates select="bm801:Berichtversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Berichtsubversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Berichtsoort" mode="copy-if-exists"/>
			<!-- als Vecozo is verzender van het retourbericht dan vullen met gegevens van Vecozo, anders met de gegevens van de verzender van het heenbericht -->
			<xsl:choose>
				<xsl:when test="$VerzenderRetourbericht = 'Vecozo'">
					<bm802:VerzenderRol>
						<xsl:value-of select="$VerzenderRolVecozo"/>
					</bm802:VerzenderRol>
				</xsl:when>
				<xsl:otherwise>
					<bm802:Verzender><xsl:value-of select="bm801:Ontvanger"/></bm802:Verzender>
					<bm802:VerzenderRol><xsl:value-of select="bm801:OntvangerRol"/></bm802:VerzenderRol>
				</xsl:otherwise>
			</xsl:choose>
			<!-- Ontvanger in retourbericht is Verzender uit het heenbericht -->
			<bm802:Ontvanger><xsl:value-of select="bm801:Verzender"/></bm802:Ontvanger>
			<!-- OntvangerRol in retourbericht is VerzenderRol uit het heenbericht -->
			<bm802:OntvangerRol><xsl:value-of select="bm801:VerzenderRol"/></bm802:OntvangerRol>
			<bm802:Verzenddatum><xsl:value-of select="$HuidigeDatum"/></bm802:Verzenddatum>
			<!-- als Referentienummer van retourbericht het Referentienummer van het heenbericht hanteren -->
			<xsl:apply-templates select="bm801:Referentienummer" mode="copy-if-exists"/>
			<!-- feedback klasse Header toevoegen -->
			<xsl:copy-of select="$rc003"/>
			<xsl:copy-of select="$rc006"/>
			<xsl:copy-of select="$vc001"/>
			<xsl:copy-of select="$vc007"/>
			<xsl:copy-of select="$vc009"/>
			<xsl:copy-of select="$vc011"/>
		</bm802:Header>
	</xsl:template>
		
	<xsl:template match="bm801:Overzicht">
		<!-- klasse Overzicht volledig retourneren -->		
		<bm802:Overzicht>
			<xsl:apply-templates select="bm801:TotaalBedragDC"/>
			<!-- als Vecozo is verzender van het retourbericht dan klasse TotaalToegekendBedragDC toevoegen. De bedragen zijn op basis van de uitgevoerde controles in deze XSLT altijd nul. -->
			<xsl:if test="$VerzenderRetourbericht = 'Vecozo'">
				<bm802:TotaalToegekendBedragDC>
					<bm802:Bedrag>0.00</bm802:Bedrag>
					<bm802:DebetCreditCode>D</bm802:DebetCreditCode>
				</bm802:TotaalToegekendBedragDC>
			</xsl:if>	
			<!-- feedback klasse Overzicht toevoegen -->
			<xsl:copy-of select="$vc002"/>
		</bm802:Overzicht>
	</xsl:template>				

	<xsl:template match="bm801:TotaalBedragDC">
		<!-- klasse TotaalBedragDC is onderdeel van Overzicht, alle gegevens retourneren -->
		<bm802:TotaalBedragDC>
			<xsl:apply-templates select="bm801:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:DebetCreditCode" mode="copy-if-exists"/>
			<!-- feedback klasse TotaalBedragDC toevoegen -->
			<xsl:copy-of select="$rc014"/>
		</bm802:TotaalBedragDC>
	</xsl:template>			
		
	<xsl:template match="bm801:Betaalopdracht">
		<bm802:Betaalopdracht>
			<!-- retourneer identificerende gegevens van Betaalopdracht -->
			<xsl:apply-templates select="bm801:UzoviNummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Categorie" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Begunstigde" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Betalingsomschrijving" mode="copy-if-exists"/>
			<!-- controles klasse Betaalopdracht uitvoeren, eerst subklasses -->
			<xsl:apply-templates select="bm801:BedragDC"/>
			<xsl:apply-templates select="bm801:RekeningBegunstigde"/>
			<xsl:apply-templates select="bm801:Betaalopdrachtspecificatie"/>
			<!-- RC008: Categorie moet voorkomen in BetaalopdrachtcategorieWlz codelijst. -->
				<xsl:call-template name="rcCode_vs_Peildatum">
					<xsl:with-param name="Codelijst" select="'codelijsten/CL0025-CAK.xml'"/>
					<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9651'"/>
					<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
					<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
					<xsl:with-param name="Code" select="bm801:Categorie"/>
					<xsl:with-param name="Peildatum" select="geenpeildatum"/>
				</xsl:call-template>
			<!-- RC009: TypeBegunstigde moet voorkomen in Type Begunstigde. -->
				<xsl:call-template name="rcCode_vs_Peildatum">
					<xsl:with-param name="Codelijst" select="'codelijsten/CL0026-CAK.xml'"/>
					<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9652'"/>
					<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
					<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
					<xsl:with-param name="Code" select="bm801:TypeBegunstigde"/>
					<xsl:with-param name="Peildatum" select="geenpeildatum"/>
				</xsl:call-template>
			<!-- VC012: IF TypeBegunstigde = 06, THEN Categorie = 4 - Alleen categorie hulpmiddel is mogelijk bij type begunstigde gemeente. -->
				<xsl:call-template name="rc9644">
					<xsl:with-param name="TypeBegunstigde" select="bm801:TypeBegunstigde"/>
					<xsl:with-param name="Categorie" select="bm801:Categorie"/>
				</xsl:call-template>
			<!-- VC013: BedragDC included DebetCreditCode = SOM TotaalbedragSpecificatieDC included DebetCreditCode | Bedrag van de betaalopdracht is onjuist. -->
				<xsl:call-template name="rc9645">
					<xsl:with-param name="TotaalBedrag" select="bm801:BedragDC/bm801:Bedrag"/>
					<xsl:with-param name="TotaalBedragDCIndicator" select="bm801:BedragDC/bm801:DebetCreditCode"/>
					<xsl:with-param name="TotaalDebetPrestaties" select="sum(bm801:Betaalopdrachtspecificatie/bm801:TotaalBedragSpecificatieDC[bm801:DebetCreditCode = 'D']/bm801:Bedrag)"/>
					<xsl:with-param name="TotaalCreditPrestaties" select="sum(bm801:Betaalopdrachtspecificatie/bm801:TotaalBedragSpecificatieDC[bm801:DebetCreditCode = 'C']/bm801:Bedrag)"/>
				</xsl:call-template>
		</bm802:Betaalopdracht>
	</xsl:template>				

	<xsl:template match="bm801:RekeningBegunstigde">	
		<bm802:RekeningBegunstigde>
			<!-- controles klasse RekeningBegunstigde uitvoeren-->
			<!-- VC003: De waarde van het IBAN-nummer moet voldoen aan Modulo 97 proef/validatie. -->
				<xsl:call-template name="rc8988">
					<xsl:with-param name="Iban" select="bm801:Rekeningnummer"/>
				</xsl:call-template>
		</bm802:RekeningBegunstigde>
	</xsl:template>	

	<xsl:template match="bm801:BedragDC">	
		<bm802:BedragDC>
			<!-- controles klasse BedragDC uitvoeren-->
			<!-- RC013: Bedrag10MetDC/DebetCreditCode moet voorkomen in Indicatie debet/credit codelijst.. -->				
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
				<xsl:with-param name="Code" select="bm801:DebetCreditCode"/>
				<xsl:with-param name="Peildatum" select="geenpeildatum"/>
			</xsl:call-template>
		</bm802:BedragDC>
	</xsl:template>	

	<xsl:template match="bm801:Betaalopdrachtspecificatie">
		<bm802:Betaalopdrachtspecificatie>
			<!-- retourneer identificerende gegevens van Betaalopdrachtspecificatie -->
			<xsl:apply-templates select="bm801:Zorgjaar" mode="copy-if-exists"/>
			<!-- controles klasse Betaalopdrachtspecificatie uitvoeren, eerst subklasses -->
 			<xsl:apply-templates select="bm801:HonorariumkostenDC"/>		
			<xsl:apply-templates select="bm801:TechniekkostenDC"/>			
			<xsl:apply-templates select="bm801:ReiskostenDC"/>
			<xsl:apply-templates select="bm801:TotaalBedragSpecificatieDC"/>
			<!-- VC006: IF BetaalopdrachtCategorie = 1, THEN TotaalbedragSpecificatieDC included DebetCreditCode = HonorariumKostenDC +  TechniekKostenDC  + ReisKostenDC included DebetCreditCode | Totaalbedrag ontbreekt of is onjuist. -->
			<xsl:call-template name="rc8991">
				<xsl:with-param name="HonorariumkostenBedrag" select="bm801:HonorariumkostenDC/bm801:Bedrag"/>
				<xsl:with-param name="HonorariumkostenDC" select="bm801:HonorariumkostenDC/bm801:DebetCreditCode"/>
				<xsl:with-param name="TechniekkostenBedrag" select="bm801:TechniekkostenDC/bm801:Bedrag"/>
				<xsl:with-param name="TechniekkostenDC" select="bm801:TechniekkostenDC/bm801:DebetCreditCode"/>
				<xsl:with-param name="ReiskostenBedrag" select="bm801:ReiskostenDC/bm801:Bedrag"/>
				<xsl:with-param name="ReiskostenDC" select="bm801:ReiskostenDC/bm801:DebetCreditCode"/>
				<xsl:with-param name="TotaalBedragSpecificatieBedrag" select="bm801:TotaalBedragSpecificatieDC/bm801:Bedrag"/>
				<xsl:with-param name="TotaalBedragSpecificatieDC" select="bm801:TotaalBedragSpecificatieDC/bm801:DebetCreditCode"/>
				<xsl:with-param name="Categorie" select="../bm801:Categorie"/>
			</xsl:call-template>
			<!-- VC014:  IF Categorie = 3, THEN EXIST AantalDagen | AantalDagen ontbreekt of is onjuist. -->
			<xsl:call-template name="rc9646">
				<xsl:with-param name="AantalDagen" select="bm801:AantalDagen"/>
				<xsl:with-param name="Categorie" select="../bm801:Categorie"/>
			</xsl:call-template>
			<!-- VC015: IF Categorie  <> 1, THEN NOT EXIST HonorariumkostenDC, TechniekkostenDC, ReiskostenDC | Honorariumkosten, Techniekkosten en Reiskosten mag niet voorkomen. -->
			<xsl:call-template name="rc9647">
				<xsl:with-param name="HonorariumkostenBedrag" select="bm801:HonorariumkostenDC/bm801:Bedrag"/>
				<xsl:with-param name="HonorariumkostenDC" select="bm801:HonorariumkostenDC/bm801:DebetCreditCode"/>
				<xsl:with-param name="TechniekkostenBedrag" select="bm801:TechniekkostenDC/bm801:Bedrag"/>
				<xsl:with-param name="TechniekkostenDC" select="bm801:TechniekkostenDC/bm801:DebetCreditCode"/>
				<xsl:with-param name="ReiskostenBedrag" select="bm801:ReiskostenDC/bm801:Bedrag"/>
				<xsl:with-param name="ReiskostenDC" select="bm801:ReiskostenDC/bm801:DebetCreditCode"/>
				<xsl:with-param name="Categorie" select="../bm801:Categorie"/>
			</xsl:call-template>
			<!-- VC016:  IF Categorie = 1|2|4, THEN NOT EXIST AantalDagen | AantalDagen mag niet voorkomen. -->
			<xsl:call-template name="rc9650">
				<xsl:with-param name="AantalDagen" select="bm801:AantalDagen"/>
				<xsl:with-param name="Categorie" select="../bm801:Categorie"/>
			</xsl:call-template>			
		</bm802:Betaalopdrachtspecificatie>
	</xsl:template>
		
	<xsl:template match="bm801:HonorariumkostenDC">	
		<bm802:HonorariumkostenDC>
			<!-- controles klasse HonorariumkostenDC uitvoeren-->
			<!-- RC013: Bedrag10MetDC/DebetCreditCode moet voorkomen in Indicatie debet/credit codelijst.. -->				
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
				<xsl:with-param name="Code" select="bm801:DebetCreditCode"/>
				<xsl:with-param name="Peildatum" select="geenpeildatum"/>
			</xsl:call-template>
		</bm802:HonorariumkostenDC>
	</xsl:template>	
		
	<xsl:template match="bm801:TechniekkostenDC">	
		<bm802:TechniekkostenDC>
			<!-- controles klasse TechniekkostenDC uitvoeren-->
			<!-- RC013: Bedrag10MetDC/DebetCreditCode moet voorkomen in Indicatie debet/credit codelijst.. -->				
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
				<xsl:with-param name="Code" select="bm801:DebetCreditCode"/>
				<xsl:with-param name="Peildatum" select="geenpeildatum"/>
			</xsl:call-template>
		</bm802:TechniekkostenDC>
	</xsl:template>
		
	<xsl:template match="bm801:ReiskostenDC">	
		<bm802:ReiskostenDC>
			<!-- controles klasse ReiskostenDC uitvoeren-->
			<!-- RC013: Bedrag10MetDC/DebetCreditCode moet voorkomen in Indicatie debet/credit codelijst.. -->				
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
				<xsl:with-param name="Code" select="bm801:DebetCreditCode"/>
				<xsl:with-param name="Peildatum" select="geenpeildatum"/>
			</xsl:call-template>
		</bm802:ReiskostenDC>
	</xsl:template>	
		
	<xsl:template match="bm801:TotaalBedragSpecificatieDC">	
		<bm802:TotaalBedragSpecificatieDC>
			<!-- controles klasse TotaalBedragSpecificatieDC uitvoeren-->
			<!-- RC013: Bedrag10MetDC/DebetCreditCode moet voorkomen in Indicatie debet/credit codelijst.. -->				
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
				<xsl:with-param name="Code" select="bm801:DebetCreditCode"/>
				<xsl:with-param name="Peildatum" select="geenpeildatum"/>
			</xsl:call-template>
		</bm802:TotaalBedragSpecificatieDC>
	</xsl:template>	
			
	<!-- Copy template: als een enkel element voorkomt, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/betaalopdrachtmondzorg/bm801/v2_0']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat('bm802:',local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>