<?xml version="1.0" encoding="UTF-8"?>
<!-- bm802_538v1.0_VALXSLTu1, januari 2024 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:cod="http://ei.vektis.nl/codelijsten/v1"
xmlns:bm802="http://ei.vektis.nl/betaalopdrachtmondzorg/bm802/v2_0">


	<!-- VALXSLT controle retourbericht verzekeraar door Vecozo -->
	<xsl:import href="rcDatum_vs_Huidigedatum.xslt"/>
  	<xsl:import href="rc8028.xslt"/>
	<xsl:import href="rc9262b.xslt"/>
	<xsl:import href="rc9263b.xslt"/>
		
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
		
	<xsl:variable name="Berichtsoort" select="//bm802:Bericht/bm802:Header/bm802:Berichtsoort"/>
	<xsl:variable name="Verzenddatum" select="//bm802:Bericht/bm802:Header/bm802:Verzenddatum"/>
		
	<xsl:template match="bm802:Bericht">
		<bm802:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/betaalopdrachtmondzorg/bm802/v2_0 bm802v2_538.xsd</xsl:attribute>
			<xsl:apply-templates select="bm802:Header"/>
			<xsl:apply-templates select="bm802:Overzicht"/>
		</bm802:Bericht>
	</xsl:template>
		
	<xsl:template match="bm802:Header">
		<!-- retourneer klasse Header -->
		<bm802:Header>
			<xsl:apply-templates select="bm802:Berichtcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:Berichtversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:Berichtsubversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:Berichtsoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:Verzender" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:VerzenderRol" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:Ontvanger" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:OntvangerRol" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:Verzenddatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:Referentienummer" mode="copy-if-exists"/>
			<!-- eventuele feedback van de verzekeraar is voor deze controle niet relevant -->
			<!-- controles klasse Header uitvoeren -->
			<!-- VC001: De waarde van Berichtsoort moet voldoen aan de omgeving van VECOZO (productie of test) -->
			<xsl:call-template name="rc8028">
				<xsl:with-param name="Berichtsoort" select="bm802:Berichtsoort"/>
			</xsl:call-template>
			<!-- VC008: Indien Berichtcode = 538 (= Retourinformatie Betaalopdracht in de WLZ), dan VerzenderRol = 7 (= CAK). -->
			<xsl:call-template name="rc9262b">
				<xsl:with-param name="Berichtcode" select="bm802:Berichtcode"/>
				<xsl:with-param name="VerzenderRol" select="bm802:VerzenderRol"/>
			</xsl:call-template>
			<!-- VC010: Indien Berichtcode = 538 (= Retourinformatie Betaalopdracht in de WLZ), dan OntvangerRol = 5 (= Zorgkantoor). -->
			<xsl:call-template name="rc9263b">
				<xsl:with-param name="Berichtcode" select="bm802:Berichtcode"/>
				<xsl:with-param name="OntvangerRol" select="bm802:OntvangerRol"/>
			</xsl:call-template>
			<!-- VC011: De waarde van Verzenddatum moet kleiner zijn dan of gelijk zijn aan de waarde van huidige datum. -->
			<xsl:call-template name="rcDatum_vs_Huidigedatum">
				<xsl:with-param name="TeControlerenDatum" select="$Verzenddatum"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'8986'"/>
			</xsl:call-template>
		</bm802:Header>
	</xsl:template>
		
	<xsl:template match="bm802:Overzicht">	
		<!-- klasse Overzicht volledig retourneren -->
		<bm802:Overzicht>
			<xsl:apply-templates select="bm802:TotaalBedragDC"/>
			<xsl:apply-templates select="bm802:TotaalToegekendBedragDC"/>
			<!-- geen controles voor klasse Overzicht -->
		</bm802:Overzicht>
	</xsl:template>
		
	<xsl:template match="bm802:TotaalBedragDC">	
		<!-- klasse TotaalBedragDC is onderdeel van Overzicht, alle gegevens retourneren -->
		<bm802:TotaalBedragDC>
			<xsl:apply-templates select="bm802:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:DebetCreditCode" mode="copy-if-exists"/>
		</bm802:TotaalBedragDC>
	</xsl:template>			
		
	<xsl:template match="bm802:TotaalToegekendBedragDC">	
		<!-- klasse TotaalBedragDC is onderdeel van Overzicht, alle gegevens retourneren -->
		<bm802:TotaalToegekendBedragDC>
			<xsl:apply-templates select="bm802:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm802:DebetCreditCode" mode="copy-if-exists"/>
		</bm802:TotaalToegekendBedragDC>
	</xsl:template>
		
	<!-- Copy template: als een enkel element voorkomt, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/betaalopdrachtmondzorg/bm802/v2_0']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat('bm802:',local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>